@@ -27,14 +27,16 @@ build_time_vars = {'ABIFLAGS': '',
            '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
            '-fstack-protector-strong -fno-plt -fexceptions         '
            '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
-           '-mfpu=neon -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection',
+           '-fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug -march=armv7-a '
+           '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fstack-protector-strong '
+           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug -march=armv7-a '
+           '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fstack-protector-strong '
+           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -43,7 +45,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                      '-fstack-protector-strong -fno-plt -fexceptions         '
                      '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                     '-Werror=format-security         -fstack-clash-protection',
+                     '-Werror=format-security         -fstack-clash-protection '
+                     '-g -ffile-prefix-map=/build/python/src=/usr/src/debug',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -61,7 +64,8 @@ build_time_vars = {'ABIFLAGS': '',
                 '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
                 '-fstack-protector-strong -fno-plt -fexceptions         '
                 '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                "-Werror=format-security         -fstack-clash-protection' "
+                '-Werror=format-security         -fstack-clash-protection -g '
+                "-ffile-prefix-map=/build/python/src=/usr/src/debug' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
@@ -668,18 +672,22 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
+                             '-fstack-clash-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
+                             '-fstack-clash-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-fstack-clash-protection -g '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-std=c99 -Wextra -Wno-unused-result '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
@@ -688,15 +696,18 @@ build_time_vars = {'ABIFLAGS': '',
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
+              '-Werror=format-security         -fstack-clash-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection '
+              '-Werror=format-security         -fstack-clash-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection',
+              '-Werror=format-security         -fstack-clash-protection -g '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -707,14 +718,17 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
+                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
+                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
+                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -734,19 +748,22 @@ build_time_vars = {'ABIFLAGS': '',
                         '-O3 -pipe -fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                        '-fstack-clash-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                        '-fstack-clash-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-fstack-clash-protection -g '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
